@@ -13,3 +13,10 @@ if not os.environ.get('DESTDIR'):
 
 	print('Compiling gsettings schemas...')
 	subprocess.call(['glib-compile-schemas', schemadir])
+
+sourcedir = os.environ['MESON_SOURCE_ROOT']
+hooksdir = os.path.join(sourcedir, '.git', 'hooks')
+precommit = os.path.join(hooksdir, 'pre-commit')
+if os.path.lexists(precommit):
+    os.remove(precommit)
+# os.symlink('../../../libgnome-games-support/style-checker', precommit)
